from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, enable: bool, connector=repcap.Connector.Default) -> None:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RFSettings:CONNector<nr>:ENABle \n
		Snippet: driver.source.xrt.generator.rfSettings.connector.enable.set(enable = False, connector = repcap.Connector.Default) \n
		No command help available \n
			:param enable: No help available
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')"""
		param = Conversions.bool_to_str(enable)
		connector_cmd_val = self._base.get_repcap_cmd_value(connector, repcap.Connector)
		self._core.io.write(f'SOURce:XRT:GENerator<Instance>:RFSettings:CONNector{connector_cmd_val}:ENABle {param}')

	def get(self, connector=repcap.Connector.Default) -> bool:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RFSettings:CONNector<nr>:ENABle \n
		Snippet: value: bool = driver.source.xrt.generator.rfSettings.connector.enable.get(connector = repcap.Connector.Default) \n
		No command help available \n
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:return: enable: No help available"""
		connector_cmd_val = self._base.get_repcap_cmd_value(connector, repcap.Connector)
		response = self._core.io.query_str(f'SOURce:XRT:GENerator<Instance>:RFSettings:CONNector{connector_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PeakSearch:
	"""PeakSearch commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("peakSearch", core, parent)

	def get_noa_markers(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch:NOAMarkers \n
		Snippet: value: int = driver.configure.gprfMeasurement.fftSpecAn.peakSearch.get_noa_markers() \n
		Specifies the number of active peak search markers. \n
			:return: no_active_markers: Range: 0 to 5
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch:NOAMarkers?')
		return Conversions.str_to_int(response)

	def set_noa_markers(self, no_active_markers: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch:NOAMarkers \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.peakSearch.set_noa_markers(no_active_markers = 1) \n
		Specifies the number of active peak search markers. \n
			:param no_active_markers: Range: 0 to 5
		"""
		param = Conversions.decimal_value_to_str(no_active_markers)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch:NOAMarkers {param}')

	# noinspection PyTypeChecker
	class ValueStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Full_Span_Enable_0: bool: OFF | ON Configures marker 0 OFF Search from PeakRangeFrom0 to PeakRangeTo0 ON Search the full frequency span
			- Peak_Range_From_0: float: Start of peak search range for FullSpanEnable0 = OFF Range: - span / 2 to span / 2, Unit: Hz
			- Peak_Range_To_0: float: End of peak search range for FullSpanEnable0 = OFF Range: - span / 2 to span / 2, Unit: Hz
			- Full_Span_Enable_1: bool: Configures marker 1
			- Peak_Range_From_1: float: No parameter help available
			- Peak_Range_To_1: float: No parameter help available
			- Full_Span_Enable_2: bool: Configures marker 2
			- Peak_Range_From_2: float: No parameter help available
			- Peak_Range_To_2: float: No parameter help available
			- Full_Span_Enable_3: bool: Configures marker 3
			- Peak_Range_From_3: float: No parameter help available
			- Peak_Range_To_3: float: No parameter help available
			- Full_Span_Enable_4: bool: Configures marker 4
			- Peak_Range_From_4: float: No parameter help available
			- Peak_Range_To_4: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Full_Span_Enable_0'),
			ArgStruct.scalar_float('Peak_Range_From_0'),
			ArgStruct.scalar_float('Peak_Range_To_0'),
			ArgStruct.scalar_bool('Full_Span_Enable_1'),
			ArgStruct.scalar_float('Peak_Range_From_1'),
			ArgStruct.scalar_float('Peak_Range_To_1'),
			ArgStruct.scalar_bool('Full_Span_Enable_2'),
			ArgStruct.scalar_float('Peak_Range_From_2'),
			ArgStruct.scalar_float('Peak_Range_To_2'),
			ArgStruct.scalar_bool('Full_Span_Enable_3'),
			ArgStruct.scalar_float('Peak_Range_From_3'),
			ArgStruct.scalar_float('Peak_Range_To_3'),
			ArgStruct.scalar_bool('Full_Span_Enable_4'),
			ArgStruct.scalar_float('Peak_Range_From_4'),
			ArgStruct.scalar_float('Peak_Range_To_4')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Full_Span_Enable_0: bool = None
			self.Peak_Range_From_0: float = None
			self.Peak_Range_To_0: float = None
			self.Full_Span_Enable_1: bool = None
			self.Peak_Range_From_1: float = None
			self.Peak_Range_To_1: float = None
			self.Full_Span_Enable_2: bool = None
			self.Peak_Range_From_2: float = None
			self.Peak_Range_To_2: float = None
			self.Full_Span_Enable_3: bool = None
			self.Peak_Range_From_3: float = None
			self.Peak_Range_To_3: float = None
			self.Full_Span_Enable_4: bool = None
			self.Peak_Range_From_4: float = None
			self.Peak_Range_To_4: float = None

	def get_value(self) -> ValueStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch \n
		Snippet: value: ValueStruct = driver.configure.gprfMeasurement.fftSpecAn.peakSearch.get_value() \n
		Defines the peak search ranges for the five markers. In this command, the markers are labeled 0 to 4. At the graphical
		user interface, they are labeled 1 to 5. The allowed ranges, reset values and default units are identical for all markers.
		The ranges depend on the configured span, see method RsCma.Configure.GprfMeasurement.FftSpecAn.fspan. \n
			:return: structure: for return value, see the help for ValueStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch?', self.__class__.ValueStruct())

	def set_value(self, value: ValueStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.peakSearch.set_value(value = ValueStruct()) \n
		Defines the peak search ranges for the five markers. In this command, the markers are labeled 0 to 4. At the graphical
		user interface, they are labeled 1 to 5. The allowed ranges, reset values and default units are identical for all markers.
		The ranges depend on the configured span, see method RsCma.Configure.GprfMeasurement.FftSpecAn.fspan. \n
			:param value: see the help for ValueStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:PSEarch', value)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vxi:
	"""Vxi commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("vxi", core, parent)

	def get_vresource(self) -> str:
		"""SCPI: SYSTem:COMMunicate:VXI:VRESource \n
		Snippet: value: str = driver.system.communicate.vxi.get_vresource() \n
		Queries the VISA resource string for the VXI-11 protocol. \n
			:return: visa_resource: VISA resource string
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:VXI:VRESource?')
		return trim_str_response(response)

	def get_gtr(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:VXI:GTR \n
		Snippet: value: bool = driver.system.communicate.vxi.get_gtr() \n
		No command help available \n
			:return: bool_switchremote: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:VXI:GTR?')
		return Conversions.str_to_bool(response)

	def set_gtr(self, bool_switchremote: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:VXI:GTR \n
		Snippet: driver.system.communicate.vxi.set_gtr(bool_switchremote = False) \n
		No command help available \n
			:param bool_switchremote: No help available
		"""
		param = Conversions.bool_to_str(bool_switchremote)
		self._core.io.write(f'SYSTem:COMMunicate:VXI:GTR {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .......Internal.Types import DataType
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LcWord:
	"""LcWord commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("lcWord", core, parent)

	def fetch(self) -> str:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:LCWord \n
		Snippet: value: str = driver.afRf.measurement.multiEval.tones.dcs.lcWord.fetch() \n
		Queries the code number of the last detected code word that matched the expected code word. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: last_code_word: Detected DCS code number as octal number"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:LCWord?', suppressed)
		return trim_str_response(response)

	def read(self) -> str:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:LCWord \n
		Snippet: value: str = driver.afRf.measurement.multiEval.tones.dcs.lcWord.read() \n
		Queries the code number of the last detected code word that matched the expected code word. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: last_code_word: Detected DCS code number as octal number"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'READ:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:LCWord?', suppressed)
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dcs:
	"""Dcs commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dcs", core, parent)

	# noinspection PyTypeChecker
	class TimeoutStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the timeout
			- Timeout: float: Waiting for a turn-off code is aborted after this time. Range: 0.1 s to 15 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Timeout')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Timeout: float = None

	def get_timeout(self) -> TimeoutStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:TOUT \n
		Snippet: value: TimeoutStruct = driver.configure.afRf.measurement.multiEval.tones.dcs.get_timeout() \n
		Configures a timeout for completion of the first DCS measurement cycle. \n
			:return: structure: for return value, see the help for TimeoutStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:TOUT?', self.__class__.TimeoutStruct())

	def set_timeout(self, value: TimeoutStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:TOUT \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.dcs.set_timeout(value = TimeoutStruct()) \n
		Configures a timeout for completion of the first DCS measurement cycle. \n
			:param value: see the help for TimeoutStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:TOUT', value)

	def get_ec_word(self) -> str:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:ECWord \n
		Snippet: value: str = driver.configure.afRf.measurement.multiEval.tones.dcs.get_ec_word() \n
		Specifies the expected DCS code number. \n
			:return: exp_code_word: DCS code number as octal number Not allowed octal numbers are automatically rounded to the closest allowed value, see method RsCma.Source.AfRf.Generator.Tones.Dcs.cword. Range: #Q20 to #Q777
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:ECWord?')
		return trim_str_response(response)

	def set_ec_word(self, exp_code_word: str) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:ECWord \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.dcs.set_ec_word(exp_code_word = r1) \n
		Specifies the expected DCS code number. \n
			:param exp_code_word: DCS code number as octal number Not allowed octal numbers are automatically rounded to the closest allowed value, see method RsCma.Source.AfRf.Generator.Tones.Dcs.cword. Range: #Q20 to #Q777
		"""
		param = Conversions.value_to_str(exp_code_word)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:ECWord {param}')

	def get_imodulation(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:IMODulation \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.tones.dcs.get_imodulation() \n
		Enables or disables the inversion of the FSK demodulation polarity. \n
			:return: imodulation: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:IMODulation?')
		return Conversions.str_to_bool(response)

	def set_imodulation(self, imodulation: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:IMODulation \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.dcs.set_imodulation(imodulation = False) \n
		Enables or disables the inversion of the FSK demodulation polarity. \n
			:param imodulation: OFF | ON
		"""
		param = Conversions.bool_to_str(imodulation)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DCS:IMODulation {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def rrc(self):
		"""rrc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rrc'):
			from .FilterPy_.Rrc import Rrc
			self._rrc = Rrc(self._core, self._base)
		return self._rrc

	# noinspection PyTypeChecker
	def get_value(self) -> enums.PulseShapingUserFilter:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:DMR:FILTer \n
		Snippet: value: enums.PulseShapingUserFilter = driver.configure.vse.measurement.dmr.filterPy.get_value() \n
		Queries the filter type used for pulse shaping for DMR. \n
			:return: filter_py: RCOS
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:DMR:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.PulseShapingUserFilter)

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpdifLeft:
	"""SpdifLeft commands group definition. 6 total commands, 2 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spdifLeft", core, parent)

	@property
	def sequence(self):
		"""sequence commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_sequence'):
			from .SpdifLeft_.Sequence import Sequence
			self._sequence = Sequence(self._core, self._base)
		return self._sequence

	@property
	def repetitions(self):
		"""repetitions commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_repetitions'):
			from .SpdifLeft_.Repetitions import Repetitions
			self._repetitions = Repetitions(self._core, self._base)
		return self._repetitions

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Length: int: Length of the tone sequence (number of digits)
			- Sequence: List[str]: Dialed digit as string
			- Frequency_1: List[float]: Nominal tone frequency according to the tone table Unit: Hz
			- Deviation_1: List[float]: Deviation of the measured tone frequency from the nominal tone frequency Unit: Hz
			- Fequency_2: List[float]: Second nominal frequency (only relevant for dual tones) Unit: Hz
			- Deviation_2: List[float]: Deviation of the second frequency (only relevant for dual tones) Unit: Hz
			- Time: List[float]: Measured tone duration Unit: s
			- Pause: List[float]: Duration of the pause between this tone and the next tone of the sequence Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_int('Length'),
			ArgStruct('Sequence', DataType.StringList, None, False, True, 1),
			ArgStruct('Frequency_1', DataType.FloatList, None, False, True, 1),
			ArgStruct('Deviation_1', DataType.FloatList, None, False, True, 1),
			ArgStruct('Fequency_2', DataType.FloatList, None, False, True, 1),
			ArgStruct('Deviation_2', DataType.FloatList, None, False, True, 1),
			ArgStruct('Time', DataType.FloatList, None, False, True, 1),
			ArgStruct('Pause', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Length: int = None
			self.Sequence: List[str] = None
			self.Frequency_1: List[float] = None
			self.Deviation_1: List[float] = None
			self.Fequency_2: List[float] = None
			self.Deviation_2: List[float] = None
			self.Time: List[float] = None
			self.Pause: List[float] = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:SINLeft \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.tones.spdifLeft.fetch() \n
		Queries all results of a tone sequence analysis. For each tone, a sequence of results is returned: <Reliability>,
		<Length>{, <Sequence>, <Frequency1>, <Deviation1>, <Frequency2>, <Deviation2>, <Time>, <Pause>}Tone 1, {...}Tone 2, ...
		, {...}Tone <Length> \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:SINLeft?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:TONes:SINLeft \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.tones.spdifLeft.read() \n
		Queries all results of a tone sequence analysis. For each tone, a sequence of results is returned: <Reliability>,
		<Length>{, <Sequence>, <Frequency1>, <Deviation1>, <Frequency2>, <Deviation2>, <Time>, <Pause>}Tone 1, {...}Tone 2, ...
		, {...}Tone <Length> \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:TONes:SINLeft?', self.__class__.ResultData())

	def clone(self) -> 'SpdifLeft':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SpdifLeft(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demodulation:
	"""Demodulation commands group definition. 8 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demodulation", core, parent)

	@property
	def pdeviation(self):
		"""pdeviation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdeviation'):
			from .Demodulation_.Pdeviation import Pdeviation
			self._pdeviation = Pdeviation(self._core, self._base)
		return self._pdeviation

	@property
	def modDepth(self):
		"""modDepth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_modDepth'):
			from .Demodulation_.ModDepth import ModDepth
			self._modDepth = ModDepth(self._core, self._base)
		return self._modDepth

	@property
	def lsbLevel(self):
		"""lsbLevel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_lsbLevel'):
			from .Demodulation_.LsbLevel import LsbLevel
			self._lsbLevel = LsbLevel(self._core, self._base)
		return self._lsbLevel

	@property
	def usbLevel(self):
		"""usbLevel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_usbLevel'):
			from .Demodulation_.UsbLevel import UsbLevel
			self._usbLevel = UsbLevel(self._core, self._base)
		return self._usbLevel

	def clone(self) -> 'Demodulation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Demodulation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	@property
	def connector(self):
		"""connector commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_connector'):
			from .RfSettings_.Connector import Connector
			self._connector = Connector(self._core, self._base)
		return self._connector

	def get_frequency(self) -> float:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RFSettings:FREQuency \n
		Snippet: value: float = driver.source.xrt.generator.rfSettings.get_frequency() \n
		No command help available \n
			:return: frequency: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RFSettings:FREQuency \n
		Snippet: driver.source.xrt.generator.rfSettings.set_frequency(frequency = 1.0) \n
		No command help available \n
			:param frequency: No help available
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce:XRT:GENerator<Instance>:RFSettings:FREQuency {param}')

	def get_level(self) -> float:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RFSettings:LEVel \n
		Snippet: value: float = driver.source.xrt.generator.rfSettings.get_level() \n
		No command help available \n
			:return: level: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:RFSettings:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RFSettings:LEVel \n
		Snippet: driver.source.xrt.generator.rfSettings.set_level(level = 1.0) \n
		No command help available \n
			:param level: No help available
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:XRT:GENerator<Instance>:RFSettings:LEVel {param}')

	def clone(self) -> 'RfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Icoupling:
	"""Icoupling commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("icoupling", core, parent)

	def set(self, input_coupling: enums.PathCoupling, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AIN<nr>:ICOupling \n
		Snippet: driver.source.afRf.generator.audioInput.icoupling.set(input_coupling = enums.PathCoupling.AC, audioInput = repcap.AudioInput.Default) \n
		Configures whether the DC signal component is blocked at an AF IN connector, or not. \n
			:param input_coupling: AC | DC AC DC component blocked, only AC component available DC AC and DC component available
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(input_coupling, enums.PathCoupling)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:AIN{audioInput_cmd_val}:ICOupling {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.PathCoupling:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AIN<nr>:ICOupling \n
		Snippet: value: enums.PathCoupling = driver.source.afRf.generator.audioInput.icoupling.get(audioInput = repcap.AudioInput.Default) \n
		Configures whether the DC signal component is blocked at an AF IN connector, or not. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: input_coupling: AC | DC AC DC component blocked, only AC component available DC AC and DC component available"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:AIN{audioInput_cmd_val}:ICOupling?')
		return Conversions.str_to_scalar_enum(response, enums.PathCoupling)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ifsk:
	"""Ifsk commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ifsk", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:IFSK:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.tones.dcs.ifsk.get_enable() \n
		Enables or disables the inversion of the FSK modulation polarity. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:IFSK:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:IFSK:ENABle \n
		Snippet: driver.source.afRf.generator.tones.dcs.ifsk.set_enable(enable = False) \n
		Enables or disables the inversion of the FSK modulation polarity. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:DCS:IFSK:ENABle {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Latest:
	"""Latest commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("latest", core, parent)

	@property
	def specific(self):
		"""specific commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_specific'):
			from .Latest_.Specific import Specific
			self._specific = Specific(self._core, self._base)
		return self._specific

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Date: str: Date of the calibration as string
			- Time: str: Time of the calibration as string
			- Type_Py: enums.CalibType: FSCorrection | CALibration | OGCal Type of the calibration FSCorrection Correction performed in factory or service CALibration Verification in the factory OGCal Verification by the service (outgoing calibration)"""
		__meta_args_list = [
			ArgStruct.scalar_str('Date'),
			ArgStruct.scalar_str('Time'),
			ArgStruct.scalar_enum('Type_Py', enums.CalibType)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Date: str = None
			self.Time: str = None
			self.Type_Py: enums.CalibType = None

	def get(self, type_py: enums.CalibType = None) -> GetStruct:
		"""SCPI: CALibration:BASE:LATest \n
		Snippet: value: GetStruct = driver.calibration.base.latest.get(type_py = enums.CalibType.CALibration) \n
		Queries information about the latest calibration. Optionally, specify <Type> to query information about the latest
		calibration of a specific type. The information is returned as <Date>,<Time>,<Type>. \n
			:param type_py: FSCorrection | CALibration | OGCal Type of the calibration FSCorrection Correction performed in factory or service CALibration Verification in the factory OGCal Verification by the service (outgoing calibration)
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('type_py', type_py, DataType.Enum, True))
		return self._core.io.query_struct(f'CALibration:BASE:LATest? {param}'.rstrip(), self.__class__.GetStruct())

	def clone(self) -> 'Latest':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Latest(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Headers:
	"""Headers commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("headers", core, parent)

	def get(self, parser: str = None) -> bytes:
		"""SCPI: SYSTem:HELP:HEADers \n
		Snippet: value: bytes = driver.system.help.headers.get(parser = '1') \n
		No command help available \n
			:param parser: No help available
			:return: headers: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('parser', parser, DataType.String, True))
		response = self._core.io.query_bin_block_ERROR(f'SYSTem:HELP:HEADers? {param}'.rstrip())
		return response



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ttl:
	"""Ttl commands group definition. 3 total commands, 2 Sub-groups, 1 group commands
	Repeated Capability: TTL, default value after init: TTL.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ttl", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_tTL_get', 'repcap_tTL_set', repcap.TTL.Ix1)

	def repcap_tTL_set(self, enum_value: repcap.TTL) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to TTL.Default
		Default value after init: TTL.Ix1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_tTL_get(self) -> repcap.TTL:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def update(self):
		"""update commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .Ttl_.Update import Update
			self._update = Update(self._core, self._base)
		return self._update

	@property
	def direction(self):
		"""direction commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_direction'):
			from .Ttl_.Direction import Direction
			self._direction = Direction(self._core, self._base)
		return self._direction

	def set(self, pin_state: List[bool], tTL=repcap.TTL.Default) -> None:
		"""SCPI: CONFigure:BASE:TTL<Index> \n
		Snippet: driver.configure.base.ttl.set(pin_state = [True, False, True], tTL = repcap.TTL.Default) \n
		Sets or queries the individual bits of a TTL register of the CONTROL connector. A register with direction IN can only be
		queried. A register with direction OUT can be configured. Before querying the input register, update the values, see
		method RsCma.Configure.Base.Ttl.Update.set. \n
			:param pin_state: OFF | ON Comma-separated list of four values, one per bit of the register Register 1: Pin 1, 2, 3, 4 Register 2: Pin 14, 15, 16, 17 OFF = 0, ON = 1
			:param tTL: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Ttl')"""
		param = Conversions.list_to_csv_str(pin_state)
		tTL_cmd_val = self._base.get_repcap_cmd_value(tTL, repcap.TTL)
		self._core.io.write(f'CONFigure:BASE:TTL{tTL_cmd_val} {param}')

	def get(self, tTL=repcap.TTL.Default) -> List[bool]:
		"""SCPI: CONFigure:BASE:TTL<Index> \n
		Snippet: value: List[bool] = driver.configure.base.ttl.get(tTL = repcap.TTL.Default) \n
		Sets or queries the individual bits of a TTL register of the CONTROL connector. A register with direction IN can only be
		queried. A register with direction OUT can be configured. Before querying the input register, update the values, see
		method RsCma.Configure.Base.Ttl.Update.set. \n
			:param tTL: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Ttl')
			:return: pin_state: OFF | ON Comma-separated list of four values, one per bit of the register Register 1: Pin 1, 2, 3, 4 Register 2: Pin 14, 15, 16, 17 OFF = 0, ON = 1"""
		tTL_cmd_val = self._base.get_repcap_cmd_value(tTL, repcap.TTL)
		response = self._core.io.query_str(f'CONFigure:BASE:TTL{tTL_cmd_val}?')
		return Conversions.str_to_bool_list(response)

	def clone(self) -> 'Ttl':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ttl(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Password:
	"""Password commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("password", core, parent)

	@property
	def cenable(self):
		"""cenable commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_cenable'):
			from .Password_.Cenable import Cenable
			self._cenable = Cenable(self._core, self._base)
		return self._cenable

	def set_cdisable(self, user_mode: enums.UserRole) -> None:
		"""SCPI: SYSTem:BASE:PASSword:CDISable \n
		Snippet: driver.system.base.password.set_cdisable(user_mode = enums.UserRole.ADMin) \n
		No command help available \n
			:param user_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(user_mode, enums.UserRole)
		self._core.io.write(f'SYSTem:BASE:PASSword:CDISable {param}')

	def clone(self) -> 'Password':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Password(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bits:
	"""Bits commands group definition. 4 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bits", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .Bits_.All import All
			self._all = All(self._core, self._base)
		return self._all

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Bits_.Count import Count
			self._count = Count(self._core, self._base)
		return self._count

	@property
	def next(self):
		"""next commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_next'):
			from .Bits_.Next import Next
			self._next = Next(self._core, self._base)
		return self._next

	def clear(self, filter_py: str = None, mode: enums.ExpressionMode = None) -> None:
		"""SCPI: STATus:EVENt:BITS:CLEar \n
		Snippet: driver.status.event.bits.clear(filter_py = '1', mode = enums.ExpressionMode.REGex) \n
		No command help available \n
			:param filter_py: No help available
			:param mode: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('filter_py', filter_py, DataType.String, True), ArgSingle('mode', mode, DataType.Enum, True))
		self._core.io.write(f'STATus:EVENt:BITS:CLEar {param}'.rstrip())

	def clone(self) -> 'Bits':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bits(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Pusch_Qpsk: float: No parameter help available
			- Pusch_16_Qam: float: No parameter help available
			- Pusch_64_Qam: float: No parameter help available
			- Pusch_256_Qam: float: No parameter help available
			- Dmrs_Pusch_Qpsk: float: No parameter help available
			- Dmrs_Pusch_16_Qam: float: No parameter help available
			- Dmrs_Pusch_64_Qam: float: No parameter help available
			- Dmrs_Pusch_256_Qam: float: No parameter help available
			- Pucch: float: No parameter help available
			- Dmrs_Pucch: float: No parameter help available
			- Power: float: No parameter help available
			- Crest_Factor: float: No parameter help available
			- Evm_All: float: No parameter help available
			- Phys_Channel: float: No parameter help available
			- Phys_Signal: float: No parameter help available
			- Frequency_Error: float: No parameter help available
			- Sampling_Error: float: No parameter help available
			- Iq_Offset: float: No parameter help available
			- Iq_Gain_Imbalance: float: No parameter help available
			- Iq_Quadrature_Error: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Pusch_Qpsk'),
			ArgStruct.scalar_float('Pusch_16_Qam'),
			ArgStruct.scalar_float('Pusch_64_Qam'),
			ArgStruct.scalar_float('Pusch_256_Qam'),
			ArgStruct.scalar_float('Dmrs_Pusch_Qpsk'),
			ArgStruct.scalar_float('Dmrs_Pusch_16_Qam'),
			ArgStruct.scalar_float('Dmrs_Pusch_64_Qam'),
			ArgStruct.scalar_float('Dmrs_Pusch_256_Qam'),
			ArgStruct.scalar_float('Pucch'),
			ArgStruct.scalar_float('Dmrs_Pucch'),
			ArgStruct.scalar_float('Power'),
			ArgStruct.scalar_float('Crest_Factor'),
			ArgStruct.scalar_float('Evm_All'),
			ArgStruct.scalar_float('Phys_Channel'),
			ArgStruct.scalar_float('Phys_Signal'),
			ArgStruct.scalar_float('Frequency_Error'),
			ArgStruct.scalar_float('Sampling_Error'),
			ArgStruct.scalar_float('Iq_Offset'),
			ArgStruct.scalar_float('Iq_Gain_Imbalance'),
			ArgStruct.scalar_float('Iq_Quadrature_Error')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Pusch_Qpsk: float = None
			self.Pusch_16_Qam: float = None
			self.Pusch_64_Qam: float = None
			self.Pusch_256_Qam: float = None
			self.Dmrs_Pusch_Qpsk: float = None
			self.Dmrs_Pusch_16_Qam: float = None
			self.Dmrs_Pusch_64_Qam: float = None
			self.Dmrs_Pusch_256_Qam: float = None
			self.Pucch: float = None
			self.Dmrs_Pucch: float = None
			self.Power: float = None
			self.Crest_Factor: float = None
			self.Evm_All: float = None
			self.Phys_Channel: float = None
			self.Phys_Signal: float = None
			self.Frequency_Error: float = None
			self.Sampling_Error: float = None
			self.Iq_Offset: float = None
			self.Iq_Gain_Imbalance: float = None
			self.Iq_Quadrature_Error: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:VSE:MEASurement<Instance>:LTE:MODulation:CURRent \n
		Snippet: value: ResultData = driver.vse.measurement.lte.modulation.current.fetch() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:VSE:MEASurement<Instance>:LTE:MODulation:CURRent?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:VSE:MEASurement<Instance>:LTE:MODulation:CURRent \n
		Snippet: value: ResultData = driver.vse.measurement.lte.modulation.current.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:VSE:MEASurement<Instance>:LTE:MODulation:CURRent?', self.__class__.ResultData())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	# noinspection PyTypeChecker
	class FrequencyStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Frequency_1: float: No parameter help available
			- Frequency_2: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Frequency_1'),
			ArgStruct.scalar_float('Frequency_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency_1: float = None
			self.Frequency_2: float = None

	def set(self, structure: FrequencyStruct, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DTONe:FREQuency \n
		Snippet: driver.source.afRf.generator.internalGenerator.dtone.frequency.set(value = [PROPERTY_STRUCT_NAME](), internalGen = repcap.InternalGen.Default) \n
		No command help available \n
			:param structure: for set value, see the help for FrequencyStruct structure arguments.
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write_struct(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DTONe:FREQuency', structure)

	def get(self, internalGen=repcap.InternalGen.Default) -> FrequencyStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DTONe:FREQuency \n
		Snippet: value: FrequencyStruct = driver.source.afRf.generator.internalGenerator.dtone.frequency.get(internalGen = repcap.InternalGen.Default) \n
		No command help available \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: structure: for return value, see the help for FrequencyStruct structure arguments."""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		return self._core.io.query_struct(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DTONe:FREQuency?', self.__class__.FrequencyStruct())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	@property
	def application(self):
		"""application commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_application'):
			from .Display_.Application import Application
			self._application = Application(self._core, self._base)
		return self._application

	# noinspection PyTypeChecker
	def get_tab_split(self) -> enums.TabSplit:
		"""SCPI: CONFigure:DISPlay:TABSplit \n
		Snippet: value: enums.TabSplit = driver.configure.display.get_tab_split() \n
		Configures the tab mode of the GUI. \n
			:return: tab_split: TAB | SPLit TAB Merged mode, displaying a single tab at a time SPLit Split mode, displaying the generator tab on the left and the measurement tabs on the right
		"""
		response = self._core.io.query_str('CONFigure:DISPlay:TABSplit?')
		return Conversions.str_to_scalar_enum(response, enums.TabSplit)

	def set_tab_split(self, tab_split: enums.TabSplit) -> None:
		"""SCPI: CONFigure:DISPlay:TABSplit \n
		Snippet: driver.configure.display.set_tab_split(tab_split = enums.TabSplit.SPLit) \n
		Configures the tab mode of the GUI. \n
			:param tab_split: TAB | SPLit TAB Merged mode, displaying a single tab at a time SPLit Split mode, displaying the generator tab on the left and the measurement tabs on the right
		"""
		param = Conversions.enum_scalar_to_str(tab_split, enums.TabSplit)
		self._core.io.write(f'CONFigure:DISPlay:TABSplit {param}')

	def clone(self) -> 'Display':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Display(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class All:
	"""All commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("all", core, parent)

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .All_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	def clone(self) -> 'All':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = All(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserDefined:
	"""UserDefined commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("userDefined", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:UDEFined:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.dialing.scal.userDefined.get_enable() \n
		Enables or disables the user-defined tone table. The table is configured via method RsCma.Source.AfRf.Generator.Dialing.
		Scal.Frequency.value. \n
			:return: user_defined: OFF | ON ON: user-defined tone table OFF: default tone table
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:UDEFined:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, user_defined: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:UDEFined:ENABle \n
		Snippet: driver.source.afRf.generator.dialing.scal.userDefined.set_enable(user_defined = False) \n
		Enables or disables the user-defined tone table. The table is configured via method RsCma.Source.AfRf.Generator.Dialing.
		Scal.Frequency.value. \n
			:param user_defined: OFF | ON ON: user-defined tone table OFF: default tone table
		"""
		param = Conversions.bool_to_str(user_defined)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:UDEFined:ENABle {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Application:
	"""Application commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("application", core, parent)

	# noinspection PyTypeChecker
	def get_select(self) -> enums.SubTab:
		"""SCPI: DISPlay:AFRF:MEASurement<Instance>:APPLication:SELect \n
		Snippet: value: enums.SubTab = driver.display.afRf.measurement.application.get_select() \n
		No command help available \n
			:return: sub_tab: No help available
		"""
		response = self._core.io.query_str('DISPlay:AFRF:MEASurement<Instance>:APPLication:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.SubTab)

	def set_select(self, sub_tab: enums.SubTab) -> None:
		"""SCPI: DISPlay:AFRF:MEASurement<Instance>:APPLication:SELect \n
		Snippet: driver.display.afRf.measurement.application.set_select(sub_tab = enums.SubTab.AFResults) \n
		No command help available \n
			:param sub_tab: No help available
		"""
		param = Conversions.enum_scalar_to_str(sub_tab, enums.SubTab)
		self._core.io.write(f'DISPlay:AFRF:MEASurement<Instance>:APPLication:SELect {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 13 total commands, 2 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def bpass(self):
		"""bpass commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_bpass'):
			from .FilterPy_.Bpass import Bpass
			self._bpass = Bpass(self._core, self._base)
		return self._bpass

	@property
	def notch(self):
		"""notch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_notch'):
			from .FilterPy_.Notch import Notch
			self._notch = Notch(self._core, self._base)
		return self._notch

	# noinspection PyTypeChecker
	def get_lpass(self) -> enums.LowpassFilterExtended:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:LPASs \n
		Snippet: value: enums.LowpassFilterExtended = driver.configure.afRf.measurement.demodulation.filterPy.get_lpass() \n
		Configures the lowpass filter in the RF input path. \n
			:return: lowpass: OFF | F255 | F3K | F3K4 | F4K | F15K OFF Filter disabled F255, F3K, F3K4, F4K, F15K Cutoff frequency 255 Hz / 3 kHz / 3.4 kHz / 4 kHz / 15 kHz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:LPASs?')
		return Conversions.str_to_scalar_enum(response, enums.LowpassFilterExtended)

	def set_lpass(self, lowpass: enums.LowpassFilterExtended) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:LPASs \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_lpass(lowpass = enums.LowpassFilterExtended.F15K) \n
		Configures the lowpass filter in the RF input path. \n
			:param lowpass: OFF | F255 | F3K | F3K4 | F4K | F15K OFF Filter disabled F255, F3K, F3K4, F4K, F15K Cutoff frequency 255 Hz / 3 kHz / 3.4 kHz / 4 kHz / 15 kHz
		"""
		param = Conversions.enum_scalar_to_str(lowpass, enums.LowpassFilterExtended)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:LPASs {param}')

	# noinspection PyTypeChecker
	def get_hpass(self) -> enums.HighpassFilterExtended:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:HPASs \n
		Snippet: value: enums.HighpassFilterExtended = driver.configure.afRf.measurement.demodulation.filterPy.get_hpass() \n
		Configures the highpass filter in the RF input path. \n
			:return: highpass: OFF | F6 | F50 | F300 OFF Filter disabled F6, F50, F300 Cutoff frequency 6 Hz / 50 Hz / 300 Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:HPASs?')
		return Conversions.str_to_scalar_enum(response, enums.HighpassFilterExtended)

	def set_hpass(self, highpass: enums.HighpassFilterExtended) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:HPASs \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_hpass(highpass = enums.HighpassFilterExtended.F300) \n
		Configures the highpass filter in the RF input path. \n
			:param highpass: OFF | F6 | F50 | F300 OFF Filter disabled F6, F50, F300 Cutoff frequency 6 Hz / 50 Hz / 300 Hz
		"""
		param = Conversions.enum_scalar_to_str(highpass, enums.HighpassFilterExtended)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:HPASs {param}')

	# noinspection PyTypeChecker
	class DwidthStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Dwidth_Left: enums.PwrFilterType: WIDE | NARRow Wide or narrow bandwidth
			- Relative_Left: enums.Relative: RELative | CONStant Bandwidth proportional to reference frequency or constant
			- Dwidth_Right: enums.PwrFilterType: WIDE | NARRow
			- Relative_Right: enums.Relative: RELative | CONStant"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Dwidth_Left', enums.PwrFilterType),
			ArgStruct.scalar_enum('Relative_Left', enums.Relative),
			ArgStruct.scalar_enum('Dwidth_Right', enums.PwrFilterType),
			ArgStruct.scalar_enum('Relative_Right', enums.Relative)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Dwidth_Left: enums.PwrFilterType = None
			self.Relative_Left: enums.Relative = None
			self.Dwidth_Right: enums.PwrFilterType = None
			self.Relative_Right: enums.Relative = None

	# noinspection PyTypeChecker
	def get_dwidth(self) -> DwidthStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DWIDth \n
		Snippet: value: DwidthStruct = driver.configure.afRf.measurement.demodulation.filterPy.get_dwidth() \n
		Configures the bandwidth of the distortion filter in the RF input path. For FM stereo, the settings configure the left
		and the right audio channel. For other modulation types, only the <...Left> settings are relevant. The <...
		Right> settings have no effect. \n
			:return: structure: for return value, see the help for DwidthStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DWIDth?', self.__class__.DwidthStruct())

	def set_dwidth(self, value: DwidthStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DWIDth \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_dwidth(value = DwidthStruct()) \n
		Configures the bandwidth of the distortion filter in the RF input path. For FM stereo, the settings configure the left
		and the right audio channel. For other modulation types, only the <...Left> settings are relevant. The <...
		Right> settings have no effect. \n
			:param value: see the help for DwidthStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DWIDth', value)

	# noinspection PyTypeChecker
	class DfrequencyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Distor_Freq_Left: float: Range: 0 Hz to 10.5 kHz, Unit: Hz
			- Distor_Freq_Right: float: Range: 0 Hz to 10.5 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Distor_Freq_Left'),
			ArgStruct.scalar_float('Distor_Freq_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Distor_Freq_Left: float = None
			self.Distor_Freq_Right: float = None

	def get_dfrequency(self) -> DfrequencyStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DFRequency \n
		Snippet: value: DfrequencyStruct = driver.configure.afRf.measurement.demodulation.filterPy.get_dfrequency() \n
		Configures the reference frequency for single-tone measurements via the RF input path. For FM stereo, the settings
		configure the left and the right audio channel. For other modulation types, only <DistorFreqLeft> is relevant.
		<DistorFreqRight> has no effect. \n
			:return: structure: for return value, see the help for DfrequencyStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DFRequency?', self.__class__.DfrequencyStruct())

	def set_dfrequency(self, value: DfrequencyStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DFRequency \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_dfrequency(value = DfrequencyStruct()) \n
		Configures the reference frequency for single-tone measurements via the RF input path. For FM stereo, the settings
		configure the left and the right audio channel. For other modulation types, only <DistorFreqLeft> is relevant.
		<DistorFreqRight> has no effect. \n
			:param value: see the help for DfrequencyStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DFRequency', value)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.demodulation.filterPy.get_enable() \n
		Selects whether the demodulation results are measured before or after the filters in the RF input path. For FM stereo,
		the demodulation results are always measured before the filters. \n
			:return: disable: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, disable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ENABle \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_enable(disable = False) \n
		Selects whether the demodulation results are measured before or after the filters in the RF input path. For FM stereo,
		the demodulation results are always measured before the filters. \n
			:param disable: OFF | ON OFF Measure before filters ON Measure after filters
		"""
		param = Conversions.bool_to_str(disable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ENABle {param}')

	# noinspection PyTypeChecker
	def get_weighting(self) -> enums.WeightingFilter:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:WEIGhting \n
		Snippet: value: enums.WeightingFilter = driver.configure.afRf.measurement.demodulation.filterPy.get_weighting() \n
		Selects the weighting filter in the RF input path. \n
			:return: weighting: OFF | AWEighting | CCITt | CMESsage OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:WEIGhting?')
		return Conversions.str_to_scalar_enum(response, enums.WeightingFilter)

	def set_weighting(self, weighting: enums.WeightingFilter) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:WEIGhting \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_weighting(weighting = enums.WeightingFilter.AWEighting) \n
		Selects the weighting filter in the RF input path. \n
			:param weighting: OFF | AWEighting | CCITt | CMESsage OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter
		"""
		param = Conversions.enum_scalar_to_str(weighting, enums.WeightingFilter)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:WEIGhting {param}')

	# noinspection PyTypeChecker
	def get_deemphasis(self) -> enums.PreDeEmphasis:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DEEMphasis \n
		Snippet: value: enums.PreDeEmphasis = driver.configure.afRf.measurement.demodulation.filterPy.get_deemphasis() \n
		Configures the de-emphasis filter in the RF input path. \n
			:return: deemphasis: OFF | T50 | T75 | T750 OFF Filter disabled T50, T75, T750 Time constant 50 µs / 75 µs / 750 µs
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DEEMphasis?')
		return Conversions.str_to_scalar_enum(response, enums.PreDeEmphasis)

	def set_deemphasis(self, deemphasis: enums.PreDeEmphasis) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DEEMphasis \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_deemphasis(deemphasis = enums.PreDeEmphasis.OFF) \n
		Configures the de-emphasis filter in the RF input path. \n
			:param deemphasis: OFF | T50 | T75 | T750 OFF Filter disabled T50, T75, T750 Time constant 50 µs / 75 µs / 750 µs
		"""
		param = Conversions.enum_scalar_to_str(deemphasis, enums.PreDeEmphasis)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:DEEMphasis {param}')

	def get_robust_auto(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ROBustauto \n
		Snippet: value: bool = driver.configure.afRf.measurement.demodulation.filterPy.get_robust_auto() \n
		Enables or disables robust automatic mode for distortion signal filtering in the RF input path. \n
			:return: automatic_mode: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ROBustauto?')
		return Conversions.str_to_bool(response)

	def set_robust_auto(self, automatic_mode: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ROBustauto \n
		Snippet: driver.configure.afRf.measurement.demodulation.filterPy.set_robust_auto(automatic_mode = False) \n
		Enables or disables robust automatic mode for distortion signal filtering in the RF input path. \n
			:param automatic_mode: OFF | ON
		"""
		param = Conversions.bool_to_str(automatic_mode)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FILTer:ROBustauto {param}')

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dtone:
	"""Dtone commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dtone", core, parent)

	def set(self, tones_frequency: List[float], frequencyLobe=repcap.FrequencyLobe.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency<Nr>:DTONe \n
		Snippet: driver.source.afRf.generator.dialing.fdialing.frequency.dtone.set(tones_frequency = [1.1, 2.2, 3.3], frequencyLobe = repcap.FrequencyLobe.Default) \n
		Assigns frequencies to the digits available for free dialing, tone type dual tone. \n
			:param tones_frequency: Comma-separated list of 16 frequencies, assigned to the digits 0, 1, ..., 9, A, ..., F Specifying fewer frequencies leaves the remaining digits unchanged. Range: no=1/2: 60 Hz to 1000 Hz / 1200 Hz to 4000 Hz , Unit: Hz
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frequency')"""
		param = Conversions.list_to_csv_str(tones_frequency)
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency{frequencyLobe_cmd_val}:DTONe {param}')

	def get(self, frequencyLobe=repcap.FrequencyLobe.Default) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency<Nr>:DTONe \n
		Snippet: value: List[float] = driver.source.afRf.generator.dialing.fdialing.frequency.dtone.get(frequencyLobe = repcap.FrequencyLobe.Default) \n
		Assigns frequencies to the digits available for free dialing, tone type dual tone. \n
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frequency')
			:return: tones_frequency: Comma-separated list of 16 frequencies, assigned to the digits 0, 1, ..., 9, A, ..., F Specifying fewer frequencies leaves the remaining digits unchanged. Range: no=1/2: 60 Hz to 1000 Hz / 1200 Hz to 4000 Hz , Unit: Hz"""
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		response = self._core.io.query_bin_or_ascii_float_list(f'SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency{frequencyLobe_cmd_val}:DTONe?')
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tin:
	"""Tin commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tin", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.data.tin.get_enable() \n
		Enables or disables analysis of data from the TTL connector. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:ENABle \n
		Snippet: driver.configure.afRf.measurement.data.tin.set_enable(enable = False) \n
		Enables or disables analysis of data from the TTL connector. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:ENABle {param}')

	# noinspection PyTypeChecker
	def get_data(self) -> enums.ClockIn:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:DATA \n
		Snippet: value: enums.ClockIn = driver.configure.afRf.measurement.data.tin.get_data() \n
		tbd \n
			:return: data: PIN14 | PIN15
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.ClockIn)

	def set_data(self, data: enums.ClockIn) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:DATA \n
		Snippet: driver.configure.afRf.measurement.data.tin.set_data(data = enums.ClockIn.PIN14) \n
		tbd \n
			:param data: PIN14 | PIN15
		"""
		param = Conversions.enum_scalar_to_str(data, enums.ClockIn)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:DATA {param}')

	# noinspection PyTypeChecker
	def get_clock(self) -> enums.ClockIn:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:CLOCk \n
		Snippet: value: enums.ClockIn = driver.configure.afRf.measurement.data.tin.get_clock() \n
		Sets the bit rate that is expected at the TTL interface. \n
			:return: clock: PIN14 | PIN15
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:CLOCk?')
		return Conversions.str_to_scalar_enum(response, enums.ClockIn)

	def set_clock(self, clock: enums.ClockIn) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:CLOCk \n
		Snippet: driver.configure.afRf.measurement.data.tin.set_clock(clock = enums.ClockIn.PIN14) \n
		Sets the bit rate that is expected at the TTL interface. \n
			:param clock: PIN14 | PIN15
		"""
		param = Conversions.enum_scalar_to_str(clock, enums.ClockIn)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DATA:TIN:CLOCk {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RefDataAvailable:
	"""RefDataAvailable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("refDataAvailable", core, parent)

	def fetch(self) -> bool:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:RDAVailable \n
		Snippet: value: bool = driver.gprfMeasurement.spectrum.tgenerator.refDataAvailable.fetch() \n
		Queries whether valid calibration results are available (ON) or not (OFF) . \n
			:return: ref_data_state: OFF | ON"""
		response = self._core.io.query_str(f'FETCh:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:RDAVailable?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZeroSpan:
	"""ZeroSpan commands group definition. 4 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zeroSpan", core, parent)

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .ZeroSpan_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	@property
	def xvalues(self):
		"""xvalues commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xvalues'):
			from .ZeroSpan_.Xvalues import Xvalues
			self._xvalues = Xvalues(self._core, self._base)
		return self._xvalues

	def clone(self) -> 'ZeroSpan':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ZeroSpan(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voip:
	"""Voip commands group definition. 19 total commands, 3 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("voip", core, parent)

	@property
	def uri(self):
		"""uri commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_uri'):
			from .Voip_.Uri import Uri
			self._uri = Uri(self._core, self._base)
		return self._uri

	@property
	def sip(self):
		"""sip commands group. 0 Sub-classes, 6 commands."""
		if not hasattr(self, '_sip'):
			from .Voip_.Sip import Sip
			self._sip = Sip(self._core, self._base)
		return self._sip

	@property
	def ptt(self):
		"""ptt commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ptt'):
			from .Voip_.Ptt import Ptt
			self._ptt = Ptt(self._core, self._base)
		return self._ptt

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.voip.get_enable() \n
		Enables or disables VoIP. \n
			:return: vo_ip_enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, vo_ip_enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:ENABle \n
		Snippet: driver.source.afRf.generator.voip.set_enable(vo_ip_enable = False) \n
		Enables or disables VoIP. \n
			:param vo_ip_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(vo_ip_enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:VOIP:ENABle {param}')

	# noinspection PyTypeChecker
	def get_pcodec(self) -> enums.VoIpCodec:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:PCODec \n
		Snippet: value: enums.VoIpCodec = driver.source.afRf.generator.voip.get_pcodec() \n
		Queries the type of the pulse code modulation (PCM) codec. \n
			:return: vo_ip_codec: ALAW
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:PCODec?')
		return Conversions.str_to_scalar_enum(response, enums.VoIpCodec)

	def get_level(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:LEVel \n
		Snippet: value: float = driver.source.afRf.generator.voip.get_level() \n
		Specifies the audio output level for the VoIP path. For noise signals provided by an internal generator, the maximum
		allowed level is reduced by the factor 1/sqrt(2) . \n
			:return: level: Range: 0.01 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:LEVel \n
		Snippet: driver.source.afRf.generator.voip.set_level(level = 1.0) \n
		Specifies the audio output level for the VoIP path. For noise signals provided by an internal generator, the maximum
		allowed level is reduced by the factor 1/sqrt(2) . \n
			:param level: Range: 0.01 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:VOIP:LEVel {param}')

	def get_audio(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:AUDio \n
		Snippet: value: bool = driver.source.afRf.generator.voip.get_audio() \n
		Enables or disables feeding an audio signal into the VoIP path. \n
			:return: af_2_vo_ip_enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:AUDio?')
		return Conversions.str_to_bool(response)

	def set_audio(self, af_2_vo_ip_enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:AUDio \n
		Snippet: driver.source.afRf.generator.voip.set_audio(af_2_vo_ip_enable = False) \n
		Enables or disables feeding an audio signal into the VoIP path. \n
			:param af_2_vo_ip_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(af_2_vo_ip_enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:VOIP:AUDio {param}')

	# noinspection PyTypeChecker
	class FrequencyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Freq: float: RF carrier center frequency Unit: Hz
			- Chanspac: int: Channel spacing Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Freq'),
			ArgStruct.scalar_int('Chanspac')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Freq: float = None
			self.Chanspac: int = None

	def get_frequency(self) -> FrequencyStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:FREQuency \n
		Snippet: value: FrequencyStruct = driver.source.afRf.generator.voip.get_frequency() \n
		Queries the RF carrier center frequency and the channel spacing resulting from the configured frequency ID. \n
			:return: structure: for return value, see the help for FrequencyStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:VOIP:FREQuency?', self.__class__.FrequencyStruct())

	def get_fid(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:FID \n
		Snippet: value: float = driver.source.afRf.generator.voip.get_fid() \n
		Specifies the frequency ID (FID) configured at the DUT.
			INTRO_CMD_HELP: Allowed values are, with n = 0 to 39995: \n
			- 0.100 + n * 0.025
			- 0.105 + n * 0.025
			- 0.110 + n * 0.025
			- 0.115 + n * 0.025
		Resulting in: 0.100, 0.105, 0.110, 0.115, 0.125, 0.130, 0.135, 0.140, ..., 999.975, 999.980, 999.985, 999.990 \n
			:return: freq_id: Frequency ID Not allowed values are rounded to the closest allowed value. Range: 0.1 to 999.99
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:FID?')
		return Conversions.str_to_float(response)

	def set_fid(self, freq_id: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:FID \n
		Snippet: driver.source.afRf.generator.voip.set_fid(freq_id = 1.0) \n
		Specifies the frequency ID (FID) configured at the DUT.
			INTRO_CMD_HELP: Allowed values are, with n = 0 to 39995: \n
			- 0.100 + n * 0.025
			- 0.105 + n * 0.025
			- 0.110 + n * 0.025
			- 0.115 + n * 0.025
		Resulting in: 0.100, 0.105, 0.110, 0.115, 0.125, 0.130, 0.135, 0.140, ..., 999.975, 999.980, 999.985, 999.990 \n
			:param freq_id: Frequency ID Not allowed values are rounded to the closest allowed value. Range: 0.1 to 999.99
		"""
		param = Conversions.decimal_value_to_str(freq_id)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:VOIP:FID {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.VoIpSource:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP \n
		Snippet: value: enums.VoIpSource = driver.source.afRf.generator.voip.get_value() \n
		Selects an audio signal source for the VoIP path. In the current software version, the value is fixed. \n
			:return: vo_ip_source: GEN4 GEN4 Audio generator 4
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP?')
		return Conversions.str_to_scalar_enum(response, enums.VoIpSource)

	def set_value(self, vo_ip_source: enums.VoIpSource) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP \n
		Snippet: driver.source.afRf.generator.voip.set_value(vo_ip_source = enums.VoIpSource.AFI1) \n
		Selects an audio signal source for the VoIP path. In the current software version, the value is fixed. \n
			:param vo_ip_source: GEN4 GEN4 Audio generator 4
		"""
		param = Conversions.enum_scalar_to_str(vo_ip_source, enums.VoIpSource)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:VOIP {param}')

	def clone(self) -> 'Voip':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Voip(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SaveState:
	"""SaveState commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("saveState", core, parent)

	def set(self, num: float) -> None:
		"""SCPI: *SAV \n
		Snippet: driver.saveState.set(num = 1.0) \n
		Stores the current instrument settings under the specified number in an intermediate memory. The settings can be restored,
		using the command *RCL with the associated number. To save the stored instrument settings to a file, see method RsCma.
		MassMemory.Store.State.set. See also MMEMory:SAV. \n
			:param num: Range: 0 to 99
		"""
		param = Conversions.decimal_value_to_str(num)
		self._core.io.write(f'*SAV {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tones:
	"""Tones commands group definition. 16 total commands, 3 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tones", core, parent)

	@property
	def subtone(self):
		"""subtone commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_subtone'):
			from .Tones_.Subtone import Subtone
			self._subtone = Subtone(self._core, self._base)
		return self._subtone

	@property
	def ctCss(self):
		"""ctCss commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ctCss'):
			from .Tones_.CtCss import CtCss
			self._ctCss = CtCss(self._core, self._base)
		return self._ctCss

	@property
	def dcs(self):
		"""dcs commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_dcs'):
			from .Tones_.Dcs import Dcs
			self._dcs = Dcs(self._core, self._base)
		return self._dcs

	def get_fdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:FDEViation \n
		Snippet: value: float = driver.source.afRf.generator.tones.get_fdeviation() \n
		Specifies the maximum frequency deviation, used in FM mode to add a tone to the RF carrier. \n
			:return: freq_deviation: Range: 0 Hz to 10 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:FDEViation?')
		return Conversions.str_to_float(response)

	def set_fdeviation(self, freq_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:FDEViation \n
		Snippet: driver.source.afRf.generator.tones.set_fdeviation(freq_deviation = 1.0) \n
		Specifies the maximum frequency deviation, used in FM mode to add a tone to the RF carrier. \n
			:param freq_deviation: Range: 0 Hz to 10 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:FDEViation {param}')

	def get_pdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:PDEViation \n
		Snippet: value: float = driver.source.afRf.generator.tones.get_pdeviation() \n
		Specifies the maximum phase deviation, used in PM mode to add a tone to the RF carrier. \n
			:return: phase_deviation: Range: 0 rad to 10 rad, Unit: rad
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:PDEViation?')
		return Conversions.str_to_float(response)

	def set_pdeviation(self, phase_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:PDEViation \n
		Snippet: driver.source.afRf.generator.tones.set_pdeviation(phase_deviation = 1.0) \n
		Specifies the maximum phase deviation, used in PM mode to add a tone to the RF carrier. \n
			:param phase_deviation: Range: 0 rad to 10 rad, Unit: rad
		"""
		param = Conversions.decimal_value_to_str(phase_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:PDEViation {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:MDEPth \n
		Snippet: value: float = driver.source.afRf.generator.tones.get_mod_depth() \n
		Specifies the modulation depth, used in AM mode to add a tone to the RF carrier. \n
			:return: modulation_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, modulation_depth: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:MDEPth \n
		Snippet: driver.source.afRf.generator.tones.set_mod_depth(modulation_depth = 1.0) \n
		Specifies the modulation depth, used in AM mode to add a tone to the RF carrier. \n
			:param modulation_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(modulation_depth)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:MDEPth {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.ToneTypeB:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes \n
		Snippet: value: enums.ToneTypeB = driver.source.afRf.generator.tones.get_value() \n
		Selects the type of additional tones to be generated. \n
			:return: tone_type: NONE | SUBTone | CTCSs | DCS NONE No additional tones SUBTone Single subtone CTCSs Single CTCSS subaudible tone DCS DCS signal
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes?')
		return Conversions.str_to_scalar_enum(response, enums.ToneTypeB)

	def set_value(self, tone_type: enums.ToneTypeB) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes \n
		Snippet: driver.source.afRf.generator.tones.set_value(tone_type = enums.ToneTypeB.CTCSs) \n
		Selects the type of additional tones to be generated. \n
			:param tone_type: NONE | SUBTone | CTCSs | DCS NONE No additional tones SUBTone Single subtone CTCSs Single CTCSS subaudible tone DCS DCS signal
		"""
		param = Conversions.enum_scalar_to_str(tone_type, enums.ToneTypeB)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes {param}')

	def clone(self) -> 'Tones':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tones(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ssnr:
	"""Ssnr commands group definition. 7 total commands, 0 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ssnr", core, parent)

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.afRf.measurement.searchRoutines.ssnr.get_repetition() \n
		Selects whether the switched SNR measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:REPetition \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the switched SNR measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:REPetition {param}')

	# noinspection PyTypeChecker
	def get_scondition(self) -> enums.StopCondition:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCONdition \n
		Snippet: value: enums.StopCondition = driver.configure.afRf.measurement.searchRoutines.ssnr.get_scondition() \n
		Specifies the conditions for an early termination of the measurement. \n
			:return: stop_condition: NONE | SLFail
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCONdition?')
		return Conversions.str_to_scalar_enum(response, enums.StopCondition)

	def set_scondition(self, stop_condition: enums.StopCondition) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCONdition \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_scondition(stop_condition = enums.StopCondition.NONE) \n
		Specifies the conditions for an early termination of the measurement. \n
			:param stop_condition: NONE | SLFail
		"""
		param = Conversions.enum_scalar_to_str(stop_condition, enums.StopCondition)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCONdition {param}')

	def get_mo_exception(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:MOEXception \n
		Snippet: value: bool = driver.configure.afRf.measurement.searchRoutines.ssnr.get_mo_exception() \n
		Specifies if faulty or inaccurate switched SNR measurement results are rejected. \n
			:return: meas_on_exception: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:MOEXception?')
		return Conversions.str_to_bool(response)

	def set_mo_exception(self, meas_on_exception: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:MOEXception \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_mo_exception(meas_on_exception = False) \n
		Specifies if faulty or inaccurate switched SNR measurement results are rejected. \n
			:param meas_on_exception: OFF | ON
		"""
		param = Conversions.bool_to_str(meas_on_exception)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:MOEXception {param}')

	def get_scount(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCOunt \n
		Snippet: value: int = driver.configure.afRf.measurement.searchRoutines.ssnr.get_scount() \n
		The number of single routine runs used to evaluate the SNR. \n
			:return: statistic_count: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCOunt \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_scount(statistic_count = 1) \n
		The number of single routine runs used to evaluate the SNR. \n
			:param statistic_count: No help available
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:SCOunt {param}')

	# noinspection PyTypeChecker
	def get_af_source(self) -> enums.AudioConnector:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:AFSource \n
		Snippet: value: enums.AudioConnector = driver.configure.afRf.measurement.searchRoutines.ssnr.get_af_source() \n
		No command help available \n
			:return: af_source: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:AFSource?')
		return Conversions.str_to_scalar_enum(response, enums.AudioConnector)

	def set_af_source(self, af_source: enums.AudioConnector) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:AFSource \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_af_source(af_source = enums.AudioConnector.AF1O) \n
		No command help available \n
			:param af_source: No help available
		"""
		param = Conversions.enum_scalar_to_str(af_source, enums.AudioConnector)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:AFSource {param}')

	def get_crepetition(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:CREPetition \n
		Snippet: value: bool = driver.configure.afRf.measurement.searchRoutines.ssnr.get_crepetition() \n
		Sets the repetition mode for switched SNR measurements to 'Continuous'. \n
			:return: continuous_repetition: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:CREPetition?')
		return Conversions.str_to_bool(response)

	def set_crepetition(self, continuous_repetition: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:CREPetition \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_crepetition(continuous_repetition = False) \n
		Sets the repetition mode for switched SNR measurements to 'Continuous'. \n
			:param continuous_repetition: OFF | ON
		"""
		param = Conversions.bool_to_str(continuous_repetition)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:CREPetition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:RCOupling \n
		Snippet: value: bool = driver.configure.afRf.measurement.searchRoutines.ssnr.get_rcoupling() \n
		Couples the repetition mode of all switched SNR measurements. \n
			:return: repetition_coupling: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupling: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:RCOupling \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.ssnr.set_rcoupling(repetition_coupling = False) \n
		Couples the repetition mode of all switched SNR measurements. \n
			:param repetition_coupling: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupling)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SSNR:RCOupling {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Condition:
	"""Condition commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("condition", core, parent)

	def get(self, bit=repcap.Bit.Default) -> bool:
		"""SCPI: STATus:QUEStionable:BIT<bitno>:CONDition \n
		Snippet: value: bool = driver.status.questionable.bit.condition.get(bit = repcap.Bit.Default) \n
		No command help available \n
			:param bit: optional repeated capability selector. Default value: Nr8 (settable in the interface 'Bit')
			:return: register_bit: No help available"""
		bit_cmd_val = self._base.get_repcap_cmd_value(bit, repcap.Bit)
		response = self._core.io.query_str(f'STATus:QUEStionable:BIT{bit_cmd_val}:CONDition?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gcoupling:
	"""Gcoupling commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gcoupling", core, parent)

	def set(self, coupling: enums.GeneratorCoupling, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:GCOupling \n
		Snippet: driver.configure.afRf.measurement.audioInput.gcoupling.set(coupling = enums.GeneratorCoupling.GEN1, audioInput = repcap.AudioInput.Default) \n
		Couples an AF IN connector to an internal signal generator. \n
			:param coupling: OFF | GEN1 | GEN2 | GEN3 | GEN4 OFF No coupling GENn Coupled to audio generator n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(coupling, enums.GeneratorCoupling)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:GCOupling {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.GeneratorCoupling:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:GCOupling \n
		Snippet: value: enums.GeneratorCoupling = driver.configure.afRf.measurement.audioInput.gcoupling.get(audioInput = repcap.AudioInput.Default) \n
		Couples an AF IN connector to an internal signal generator. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: coupling: OFF | GEN1 | GEN2 | GEN3 | GEN4 OFF No coupling GENn Coupled to audio generator n"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:GCOupling?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorCoupling)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dcs:
	"""Dcs commands group definition. 24 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dcs", core, parent)

	@property
	def cword(self):
		"""cword commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_cword'):
			from .Dcs_.Cword import Cword
			self._cword = Cword(self._core, self._base)
		return self._cword

	@property
	def lcWord(self):
		"""lcWord commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_lcWord'):
			from .Dcs_.LcWord import LcWord
			self._lcWord = LcWord(self._core, self._base)
		return self._lcWord

	@property
	def fskDeviation(self):
		"""fskDeviation commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_fskDeviation'):
			from .Dcs_.FskDeviation import FskDeviation
			self._fskDeviation = FskDeviation(self._core, self._base)
		return self._fskDeviation

	@property
	def bitErrorRate(self):
		"""bitErrorRate commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bitErrorRate'):
			from .Dcs_.BitErrorRate import BitErrorRate
			self._bitErrorRate = BitErrorRate(self._core, self._base)
		return self._bitErrorRate

	@property
	def tocLength(self):
		"""tocLength commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tocLength'):
			from .Dcs_.TocLength import TocLength
			self._tocLength = TocLength(self._core, self._base)
		return self._tocLength

	@property
	def dmatches(self):
		"""dmatches commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_dmatches'):
			from .Dcs_.Dmatches import Dmatches
			self._dmatches = Dmatches(self._core, self._base)
		return self._dmatches

	def clone(self) -> 'Dcs':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dcs(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rbw:
	"""Rbw commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rbw", core, parent)

	def get_auto(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW:AUTO \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.freqSweep.rbw.get_auto() \n
		Enables or disables automatic configuration of the resolution bandwidth (RBW) for the frequency sweep mode. \n
			:return: rbw_auto: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW:AUTO?')
		return Conversions.str_to_bool(response)

	def set_auto(self, rbw_auto: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW:AUTO \n
		Snippet: driver.configure.gprfMeasurement.spectrum.freqSweep.rbw.set_auto(rbw_auto = False) \n
		Enables or disables automatic configuration of the resolution bandwidth (RBW) for the frequency sweep mode. \n
			:param rbw_auto: OFF | ON
		"""
		param = Conversions.bool_to_str(rbw_auto)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW:AUTO {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.freqSweep.rbw.get_value() \n
		Selects the bandwidth of the Gaussian resolution filter for the frequency sweep mode. Setting this value is only possible
		if the automatic RBW selection is switched off, see method RsCma.Configure.GprfMeasurement.Spectrum.FreqSweep.Rbw.auto. \n
			:return: rbw: You can enter values between 100 Hz and 10 MHz. The setting is rounded to the closest of the following values: 100 / 200 / 300 / 500 Hz 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 2 / 3 / 5 / 10 MHz Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW?')
		return Conversions.str_to_float(response)

	def set_value(self, rbw: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW \n
		Snippet: driver.configure.gprfMeasurement.spectrum.freqSweep.rbw.set_value(rbw = 1.0) \n
		Selects the bandwidth of the Gaussian resolution filter for the frequency sweep mode. Setting this value is only possible
		if the automatic RBW selection is switched off, see method RsCma.Configure.GprfMeasurement.Spectrum.FreqSweep.Rbw.auto. \n
			:param rbw: You can enter values between 100 Hz and 10 MHz. The setting is rounded to the closest of the following values: 100 / 200 / 300 / 500 Hz 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 2 / 3 / 5 / 10 MHz Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(rbw)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:RBW {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Custom:
	"""Custom commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("custom", core, parent)

	def get_load(self) -> str:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:CUSTom:LOAD \n
		Snippet: value: str = driver.configure.vse.measurement.custom.get_load() \n
		No command help available \n
			:return: filename: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:CUSTom:LOAD?')
		return trim_str_response(response)

	def set_load(self, filename: str) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:CUSTom:LOAD \n
		Snippet: driver.configure.vse.measurement.custom.set_load(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:CUSTom:LOAD {param}')

	def save(self, filename: str) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:CUSTom:SAVE \n
		Snippet: driver.configure.vse.measurement.custom.save(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:CUSTom:SAVE {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Notch:
	"""Notch commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("notch", core, parent)

	# noinspection PyTypeChecker
	def get_path(self) -> enums.NotchPath:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FILTer:NOTCh:PATH \n
		Snippet: value: enums.NotchPath = driver.configure.afRf.measurement.filterPy.notch.get_path() \n
		No command help available \n
			:return: path: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FILTer:NOTCh:PATH?')
		return Conversions.str_to_scalar_enum(response, enums.NotchPath)

	def set_path(self, path: enums.NotchPath) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FILTer:NOTCh:PATH \n
		Snippet: driver.configure.afRf.measurement.filterPy.notch.set_path(path = enums.NotchPath.AF) \n
		No command help available \n
			:param path: No help available
		"""
		param = Conversions.enum_scalar_to_str(path, enums.NotchPath)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FILTer:NOTCh:PATH {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Device:
	"""Device commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("device", core, parent)

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.ScreenshotFormat:
		"""SCPI: HCOPy:DEVice:FORMat \n
		Snippet: value: enums.ScreenshotFormat = driver.hardCopy.device.get_format_py() \n
		Specifies the format of screenshots created via a HCOPy command. \n
			:return: file_formats: BMP | JPG | PNG
		"""
		response = self._core.io.query_str('HCOPy:DEVice:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.ScreenshotFormat)

	def set_format_py(self, file_formats: enums.ScreenshotFormat) -> None:
		"""SCPI: HCOPy:DEVice:FORMat \n
		Snippet: driver.hardCopy.device.set_format_py(file_formats = enums.ScreenshotFormat.BMP) \n
		Specifies the format of screenshots created via a HCOPy command. \n
			:param file_formats: BMP | JPG | PNG
		"""
		param = Conversions.enum_scalar_to_str(file_formats, enums.ScreenshotFormat)
		self._core.io.write(f'HCOPy:DEVice:FORMat {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def get_locked(self) -> bool:
		"""SCPI: SENSe:BASE:REFerence:FREQuency:LOCKed \n
		Snippet: value: bool = driver.sense.base.reference.frequency.get_locked() \n
		Queries whether the reference frequency is locked or not. \n
			:return: lock: 1 | 0 1: Frequency is locked 0: Frequency is not locked
		"""
		response = self._core.io.query_str('SENSe:BASE:REFerence:FREQuency:LOCKed?')
		return Conversions.str_to_bool(response)

	def get_oven_cold(self) -> bool:
		"""SCPI: SENSe:BASE:REFerence:FREQuency:OVENcold \n
		Snippet: value: bool = driver.sense.base.reference.frequency.get_oven_cold() \n
		Queries whether an installed OCXO has completed the warm-up phase and has reached its operating temperature. \n
			:return: oven_cold: 0 | 1 0: warm-up completed, operating temperature reached 1: oven still cold, warm-up is ongoing
		"""
		response = self._core.io.query_str('SENSe:BASE:REFerence:FREQuency:OVENcold?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vphase:
	"""Vphase commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("vphase", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.vor.afSettings.vphase.get_enable() \n
		Enables or disables the VAR signal. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:ENABle \n
		Snippet: driver.source.avionics.generator.vor.afSettings.vphase.set_enable(enable = False) \n
		Enables or disables the VAR signal. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:ENABle {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:MDEPth \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.vphase.get_mod_depth() \n
		Sets the AM modulation depth for the VAR signal. The sum of the modulation depths for all enabled components must not
		exceed 100 %. \n
			:return: vor_mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, vor_mod_depth: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:MDEPth \n
		Snippet: driver.source.avionics.generator.vor.afSettings.vphase.set_mod_depth(vor_mod_depth = 1.0) \n
		Sets the AM modulation depth for the VAR signal. The sum of the modulation depths for all enabled components must not
		exceed 100 %. \n
			:param vor_mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(vor_mod_depth)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:MDEPth {param}')

	def get_bangle(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:BANGle \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.vphase.get_bangle() \n
		Sets the bearing angle from the beacon to the receiver, or vice versa, depending on the configured direction. \n
			:return: vor_phase: Range: 0 deg to 360 deg, Unit: deg
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:BANGle?')
		return Conversions.str_to_float(response)

	def set_bangle(self, vor_phase: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:BANGle \n
		Snippet: driver.source.avionics.generator.vor.afSettings.vphase.set_bangle(vor_phase = 1.0) \n
		Sets the bearing angle from the beacon to the receiver, or vice versa, depending on the configured direction. \n
			:param vor_phase: Range: 0 deg to 360 deg, Unit: deg
		"""
		param = Conversions.decimal_value_to_str(vor_phase)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:BANGle {param}')

	# noinspection PyTypeChecker
	def get_direction(self) -> enums.VphaseDirection:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:DIRection \n
		Snippet: value: enums.VphaseDirection = driver.source.avionics.generator.vor.afSettings.vphase.get_direction() \n
		Sets the bearing direction. \n
			:return: direction: TO | FROM TO The bearing angle indicates the clockwise angle between north and the line from the receiver to the beacon. FROM The bearing angle indicates the clockwise angle between north and the line from the beacon to the receiver.
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.VphaseDirection)

	def set_direction(self, direction: enums.VphaseDirection) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:DIRection \n
		Snippet: driver.source.avionics.generator.vor.afSettings.vphase.set_direction(direction = enums.VphaseDirection.FROM) \n
		Sets the bearing direction. \n
			:param direction: TO | FROM TO The bearing angle indicates the clockwise angle between north and the line from the receiver to the beacon. FROM The bearing angle indicates the clockwise angle between north and the line from the beacon to the receiver.
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.VphaseDirection)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:VPHase:DIRection {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	# noinspection PyTypeChecker
	def get_omode(self) -> enums.SupplyMode:
		"""SCPI: SENSe:BASE:POWer:OMODe \n
		Snippet: value: enums.SupplyMode = driver.sense.base.power.get_omode() \n
		Queries whether the instrument is powered by an inserted battery or by an external power supply. \n
			:return: oper_mode: BATTery | MAINs
		"""
		response = self._core.io.query_str('SENSe:BASE:POWer:OMODe?')
		return Conversions.str_to_scalar_enum(response, enums.SupplyMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 7 total commands, 7 Sub-groups, 0 group commands
	Repeated Capability: Instrument, default value after init: Instrument.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_instrument_get', 'repcap_instrument_set', repcap.Instrument.Nr1)

	def repcap_instrument_set(self, enum_value: repcap.Instrument) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Instrument.Default
		Default value after init: Instrument.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_instrument_get(self) -> repcap.Instrument:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def stopMode(self):
		"""stopMode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stopMode'):
			from .File_.StopMode import StopMode
			self._stopMode = StopMode(self._core, self._base)
		return self._stopMode

	@property
	def startMode(self):
		"""startMode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_startMode'):
			from .File_.StartMode import StartMode
			self._startMode = StartMode(self._core, self._base)
		return self._startMode

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .File_.Name import Name
			self._name = Name(self._core, self._base)
		return self._name

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .File_.FormatPy import FormatPy
			self._formatPy = FormatPy(self._core, self._base)
		return self._formatPy

	@property
	def size(self):
		"""size commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_size'):
			from .File_.Size import Size
			self._size = Size(self._core, self._base)
		return self._size

	@property
	def filterPy(self):
		"""filterPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .File_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .File_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	def clone(self) -> 'File':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = File(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Maximum:
	"""Maximum commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("maximum", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Level_Peak: float: No parameter help available
			- Level_Rms: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Level_Peak'),
			ArgStruct.scalar_float('Level_Rms')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Level_Peak: float = None
			self.Level_Rms: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:SINLeft:LEVel:DELTa:MAXimum \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.spdifLeft.level.delta.maximum.fetch() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:SINLeft:LEVel:DELTa:MAXimum?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:SINLeft:LEVel:DELTa:MAXimum \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.spdifLeft.level.delta.maximum.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:SINLeft:LEVel:DELTa:MAXimum?', self.__class__.ResultData())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AmPoints:
	"""AmPoints commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("amPoints", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:AMPoints:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.searchRoutines.rx.amPoints.get_enable() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:AMPoints:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:AMPoints:ENABle \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rx.amPoints.set_enable(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:AMPoints:ENABle {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModDepth:
	"""ModDepth commands group definition. 5 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("modDepth", core, parent)

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_trace'):
			from .ModDepth_.Trace import Trace
			self._trace = Trace(self._core, self._base)
		return self._trace

	def fetch(self) -> float:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:MDEPth \n
		Snippet: value: float = driver.afRf.measurement.searchRoutines.tsensitivity.modDepth.fetch() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: mod_depth: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:MDEPth?', suppressed)
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def calculate(self) -> enums.ResultStatus:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:MDEPth \n
		Snippet: value: enums.ResultStatus = driver.afRf.measurement.searchRoutines.tsensitivity.modDepth.calculate() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: mod_depth: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'CALCulate:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:MDEPth?', suppressed)
		return Conversions.str_to_scalar_enum(response, enums.ResultStatus)

	def read(self) -> float:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:MDEPth \n
		Snippet: value: float = driver.afRf.measurement.searchRoutines.tsensitivity.modDepth.read() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: mod_depth: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'READ:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:MDEPth?', suppressed)
		return Conversions.str_to_float(response)

	def clone(self) -> 'ModDepth':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ModDepth(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class First:
	"""First commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("first", core, parent)

	@property
	def level(self):
		"""level commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .First_.Level import Level
			self._level = Level(self._core, self._base)
		return self._level

	def get_mlevel(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:MLEVel \n
		Snippet: value: float = driver.configure.afRf.measurement.audioInput.first.get_mlevel() \n
		Specifies the maximum expected level for the AF1 IN connector. This setting is only relevant, if auto ranging is disabled.
		Use this command, if you want to set different level units, e.g. dBm (Table 'Units relevant for remote commands') , or
		set the level for both connectors independently. \n
			:return: max_level: Range: 10E-6 V to 43 V, Unit: V
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:MLEVel?')
		return Conversions.str_to_float(response)

	def set_mlevel(self, max_level: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:MLEVel \n
		Snippet: driver.configure.afRf.measurement.audioInput.first.set_mlevel(max_level = 1.0) \n
		Specifies the maximum expected level for the AF1 IN connector. This setting is only relevant, if auto ranging is disabled.
		Use this command, if you want to set different level units, e.g. dBm (Table 'Units relevant for remote commands') , or
		set the level for both connectors independently. \n
			:param max_level: Range: 10E-6 V to 43 V, Unit: V
		"""
		param = Conversions.decimal_value_to_str(max_level)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:MLEVel {param}')

	def clone(self) -> 'First':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = First(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
